#ifndef __clang_analyzer__
// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: Policy.proto
// Protobuf C++ Version: 7.36.0

#include "Policy.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::usbguard::IPC::listRulesRequest
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::listRulesResponse
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::listRules
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::appendRuleRequest
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::appendRuleResponse
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::appendRule
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::removeRuleRequest
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::removeRuleResponse
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::removeRule
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::checkIPCPermissionsRequest
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::checkIPCPermissionsResponse
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
        // ::usbguard::IPC::checkIPCPermissions
        {&::_pbi::kDescriptorMethods, &::descriptor_table_Policy_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace usbguard {
namespace IPC {
class removeRuleResponse::_Internal {
 public:
  using HasBits = decltype(::std::declval<removeRuleResponse>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(removeRuleResponse, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000001) ^ 0x00000001) != 0;
  }
};

constexpr removeRuleResponse::ParseTableT_ removeRuleResponse::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(removeRuleResponse, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::removeRuleResponse>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required uint32 id = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(removeRuleResponse, _impl_.id_), 0>(),
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(removeRuleResponse, _impl_.id_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required uint32 id = 1;
      {PROTOBUF_FIELD_OFFSET(removeRuleResponse, _impl_.id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr removeRuleResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : id_{0u} {}

template <typename>
constexpr removeRuleResponse::removeRuleResponse(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL removeRuleResponse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) removeRuleResponse(arena);
}
constexpr auto removeRuleResponse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(removeRuleResponse), alignof(removeRuleResponse));
}
constexpr auto removeRuleResponse::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          removeRuleResponse::IsInitializedImpl,
          &removeRuleResponse::MergeImpl,
          Super_::GetNewImpl<removeRuleResponse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &removeRuleResponse::SharedDtor,
          Super_::GetClearImpl<removeRuleResponse>(), &removeRuleResponse::ByteSizeLong,
              &removeRuleResponse::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(removeRuleResponse, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[7],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct removeRuleResponseGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr removeRuleResponseGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 removeRuleResponse_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(removeRuleResponse::InternalGenerateClassData_(
            _default, &removeRuleResponse_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<removeRuleResponse>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~removeRuleResponseGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) removeRuleResponse _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<removeRuleResponse>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(removeRuleResponseGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST removeRuleResponseGlobalsTypeInternal removeRuleResponse_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* removeRuleResponse_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return removeRuleResponse_globals_.GetClassData();
#else
  return removeRuleResponse_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class removeRuleRequest::_Internal {
 public:
  using HasBits = decltype(::std::declval<removeRuleRequest>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(removeRuleRequest, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000001) ^ 0x00000001) != 0;
  }
};

constexpr removeRuleRequest::ParseTableT_ removeRuleRequest::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(removeRuleRequest, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::removeRuleRequest>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required uint32 id = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(removeRuleRequest, _impl_.id_), 0>(),
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(removeRuleRequest, _impl_.id_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required uint32 id = 1;
      {PROTOBUF_FIELD_OFFSET(removeRuleRequest, _impl_.id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr removeRuleRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : id_{0u} {}

template <typename>
constexpr removeRuleRequest::removeRuleRequest(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL removeRuleRequest::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) removeRuleRequest(arena);
}
constexpr auto removeRuleRequest::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(removeRuleRequest), alignof(removeRuleRequest));
}
constexpr auto removeRuleRequest::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          removeRuleRequest::IsInitializedImpl,
          &removeRuleRequest::MergeImpl,
          Super_::GetNewImpl<removeRuleRequest>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &removeRuleRequest::SharedDtor,
          Super_::GetClearImpl<removeRuleRequest>(), &removeRuleRequest::ByteSizeLong,
              &removeRuleRequest::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(removeRuleRequest, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[6],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct removeRuleRequestGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr removeRuleRequestGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 removeRuleRequest_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(removeRuleRequest::InternalGenerateClassData_(
            _default, &removeRuleRequest_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<removeRuleRequest>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~removeRuleRequestGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) removeRuleRequest _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<removeRuleRequest>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(removeRuleRequestGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST removeRuleRequestGlobalsTypeInternal removeRuleRequest_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* removeRuleRequest_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return removeRuleRequest_globals_.GetClassData();
#else
  return removeRuleRequest_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class listRulesRequest::_Internal {
 public:
  using HasBits = decltype(::std::declval<listRulesRequest>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(listRulesRequest, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000001) ^ 0x00000001) != 0;
  }
};

constexpr listRulesRequest::ParseTableT_ listRulesRequest::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(listRulesRequest, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::listRulesRequest>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required string label = 1;
      {::_pbi::TcParser::FastBS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(listRulesRequest, _impl_.label_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required string label = 1;
      {PROTOBUF_FIELD_OFFSET(listRulesRequest, _impl_.label_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr listRulesRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : label_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr listRulesRequest::listRulesRequest(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL listRulesRequest::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) listRulesRequest(arena);
}
constexpr auto listRulesRequest::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(listRulesRequest), alignof(listRulesRequest));
}
constexpr auto listRulesRequest::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          listRulesRequest::IsInitializedImpl,
          &listRulesRequest::MergeImpl,
          Super_::GetNewImpl<listRulesRequest>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &listRulesRequest::SharedDtor,
          Super_::GetClearImpl<listRulesRequest>(), &listRulesRequest::ByteSizeLong,
              &listRulesRequest::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(listRulesRequest, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct listRulesRequestGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr listRulesRequestGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 listRulesRequest_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(listRulesRequest::InternalGenerateClassData_(
            _default, &listRulesRequest_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<listRulesRequest>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~listRulesRequestGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) listRulesRequest _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<listRulesRequest>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(listRulesRequestGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST listRulesRequestGlobalsTypeInternal listRulesRequest_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* listRulesRequest_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return listRulesRequest_globals_.GetClassData();
#else
  return listRulesRequest_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class checkIPCPermissionsResponse::_Internal {
 public:
  using HasBits = decltype(::std::declval<checkIPCPermissionsResponse>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(checkIPCPermissionsResponse, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000001) ^ 0x00000001) != 0;
  }
};

constexpr checkIPCPermissionsResponse::ParseTableT_ checkIPCPermissionsResponse::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(checkIPCPermissionsResponse, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::checkIPCPermissionsResponse>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required bool permit = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(checkIPCPermissionsResponse, _impl_.permit_), 0>(),
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissionsResponse, _impl_.permit_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required bool permit = 1;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissionsResponse, _impl_.permit_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr checkIPCPermissionsResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : permit_{false} {}

template <typename>
constexpr checkIPCPermissionsResponse::checkIPCPermissionsResponse(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL checkIPCPermissionsResponse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) checkIPCPermissionsResponse(arena);
}
constexpr auto checkIPCPermissionsResponse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(checkIPCPermissionsResponse), alignof(checkIPCPermissionsResponse));
}
constexpr auto checkIPCPermissionsResponse::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          checkIPCPermissionsResponse::IsInitializedImpl,
          &checkIPCPermissionsResponse::MergeImpl,
          Super_::GetNewImpl<checkIPCPermissionsResponse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &checkIPCPermissionsResponse::SharedDtor,
          Super_::GetClearImpl<checkIPCPermissionsResponse>(), &checkIPCPermissionsResponse::ByteSizeLong,
              &checkIPCPermissionsResponse::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(checkIPCPermissionsResponse, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[10],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct checkIPCPermissionsResponseGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr checkIPCPermissionsResponseGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 checkIPCPermissionsResponse_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(checkIPCPermissionsResponse::InternalGenerateClassData_(
            _default, &checkIPCPermissionsResponse_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<checkIPCPermissionsResponse>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~checkIPCPermissionsResponseGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) checkIPCPermissionsResponse _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<checkIPCPermissionsResponse>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(checkIPCPermissionsResponseGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST checkIPCPermissionsResponseGlobalsTypeInternal checkIPCPermissionsResponse_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* checkIPCPermissionsResponse_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return checkIPCPermissionsResponse_globals_.GetClassData();
#else
  return checkIPCPermissionsResponse_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class checkIPCPermissionsRequest::_Internal {
 public:
  using HasBits = decltype(::std::declval<checkIPCPermissionsRequest>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x0000000f) ^ 0x0000000f) != 0;
  }
};

constexpr checkIPCPermissionsRequest::ParseTableT_ checkIPCPermissionsRequest::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_._has_bits_),
      0, // no _extensions_
      4, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967280,  // skipmap
      offsetof(ParseTableT_, field_entries),
      4,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::checkIPCPermissionsRequest>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required string privilege = 4;
      {::_pbi::TcParser::FastBS1,
       {34, 1, 0,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.privilege_)}},
      // required uint32 uid = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(checkIPCPermissionsRequest, _impl_.uid_), 2>(),
       {8, 2, 0,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.uid_)}},
      // required uint32 gid = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(checkIPCPermissionsRequest, _impl_.gid_), 3>(),
       {16, 3, 0,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.gid_)}},
      // required string section = 3;
      {::_pbi::TcParser::FastBS1,
       {26, 0, 0,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.section_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required uint32 uid = 1;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.uid_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // required uint32 gid = 2;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.gid_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // required string section = 3;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.section_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
      // required string privilege = 4;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.privilege_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr checkIPCPermissionsRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : section_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        privilege_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        uid_{0u},
        gid_{0u} {}

template <typename>
constexpr checkIPCPermissionsRequest::checkIPCPermissionsRequest(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL checkIPCPermissionsRequest::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) checkIPCPermissionsRequest(arena);
}
constexpr auto checkIPCPermissionsRequest::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(checkIPCPermissionsRequest), alignof(checkIPCPermissionsRequest));
}
constexpr auto checkIPCPermissionsRequest::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          checkIPCPermissionsRequest::IsInitializedImpl,
          &checkIPCPermissionsRequest::MergeImpl,
          Super_::GetNewImpl<checkIPCPermissionsRequest>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &checkIPCPermissionsRequest::SharedDtor,
          Super_::GetClearImpl<checkIPCPermissionsRequest>(), &checkIPCPermissionsRequest::ByteSizeLong,
              &checkIPCPermissionsRequest::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[9],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct checkIPCPermissionsRequestGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr checkIPCPermissionsRequestGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 checkIPCPermissionsRequest_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(checkIPCPermissionsRequest::InternalGenerateClassData_(
            _default, &checkIPCPermissionsRequest_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<checkIPCPermissionsRequest>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~checkIPCPermissionsRequestGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) checkIPCPermissionsRequest _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<checkIPCPermissionsRequest>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequestGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST checkIPCPermissionsRequestGlobalsTypeInternal checkIPCPermissionsRequest_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* checkIPCPermissionsRequest_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return checkIPCPermissionsRequest_globals_.GetClassData();
#else
  return checkIPCPermissionsRequest_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class appendRuleResponse::_Internal {
 public:
  using HasBits = decltype(::std::declval<appendRuleResponse>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(appendRuleResponse, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000001) ^ 0x00000001) != 0;
  }
};

constexpr appendRuleResponse::ParseTableT_ appendRuleResponse::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(appendRuleResponse, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::appendRuleResponse>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // required uint32 id = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(appendRuleResponse, _impl_.id_), 0>(),
       {8, 0, 0,
        PROTOBUF_FIELD_OFFSET(appendRuleResponse, _impl_.id_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required uint32 id = 1;
      {PROTOBUF_FIELD_OFFSET(appendRuleResponse, _impl_.id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr appendRuleResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : id_{0u} {}

template <typename>
constexpr appendRuleResponse::appendRuleResponse(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL appendRuleResponse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) appendRuleResponse(arena);
}
constexpr auto appendRuleResponse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(appendRuleResponse), alignof(appendRuleResponse));
}
constexpr auto appendRuleResponse::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          appendRuleResponse::IsInitializedImpl,
          &appendRuleResponse::MergeImpl,
          Super_::GetNewImpl<appendRuleResponse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &appendRuleResponse::SharedDtor,
          Super_::GetClearImpl<appendRuleResponse>(), &appendRuleResponse::ByteSizeLong,
              &appendRuleResponse::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(appendRuleResponse, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[4],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct appendRuleResponseGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr appendRuleResponseGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 appendRuleResponse_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(appendRuleResponse::InternalGenerateClassData_(
            _default, &appendRuleResponse_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<appendRuleResponse>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~appendRuleResponseGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) appendRuleResponse _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<appendRuleResponse>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(appendRuleResponseGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST appendRuleResponseGlobalsTypeInternal appendRuleResponse_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* appendRuleResponse_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return appendRuleResponse_globals_.GetClassData();
#else
  return appendRuleResponse_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class appendRuleRequest::_Internal {
 public:
  using HasBits = decltype(::std::declval<appendRuleRequest>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000007) ^ 0x00000007) != 0;
  }
};

constexpr appendRuleRequest::ParseTableT_ appendRuleRequest::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::appendRuleRequest>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // required string rule = 1;
      {::_pbi::TcParser::FastBS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.rule_)}},
      // required uint32 parent_id = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(appendRuleRequest, _impl_.parent_id_), 1>(),
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.parent_id_)}},
      // required bool permanent = 3;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(appendRuleRequest, _impl_.permanent_), 2>(),
       {24, 2, 0,
        PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.permanent_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required string rule = 1;
      {PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.rule_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kBytes | ::_fl::kRepAString)},
      // required uint32 parent_id = 2;
      {PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.parent_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // required bool permanent = 3;
      {PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.permanent_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    }},
    // no aux_entries
    {{
    }},
  };
}


inline constexpr appendRuleRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : rule_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        parent_id_{0u},
        permanent_{false} {}

template <typename>
constexpr appendRuleRequest::appendRuleRequest(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL appendRuleRequest::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) appendRuleRequest(arena);
}
constexpr auto appendRuleRequest::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(appendRuleRequest), alignof(appendRuleRequest));
}
constexpr auto appendRuleRequest::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          appendRuleRequest::IsInitializedImpl,
          &appendRuleRequest::MergeImpl,
          Super_::GetNewImpl<appendRuleRequest>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &appendRuleRequest::SharedDtor,
          Super_::GetClearImpl<appendRuleRequest>(), &appendRuleRequest::ByteSizeLong,
              &appendRuleRequest::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct appendRuleRequestGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr appendRuleRequestGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 appendRuleRequest_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(appendRuleRequest::InternalGenerateClassData_(
            _default, &appendRuleRequest_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<appendRuleRequest>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~appendRuleRequestGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) appendRuleRequest _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<appendRuleRequest>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(appendRuleRequestGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST appendRuleRequestGlobalsTypeInternal appendRuleRequest_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* appendRuleRequest_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return appendRuleRequest_globals_.GetClassData();
#else
  return appendRuleRequest_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class removeRule::_Internal {
 public:
  using HasBits = decltype(::std::declval<removeRule>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(removeRule, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000003) ^ 0x00000003) != 0;
  }
};

constexpr removeRule::ParseTableT_ removeRule::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(removeRule, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      3,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::removeRule>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // required .usbguard.IPC.MessageHeader header = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(removeRule, _impl_.header_)}},
      // required .usbguard.IPC.removeRuleRequest request = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 1, 1,
        PROTOBUF_FIELD_OFFSET(removeRule, _impl_.request_)}},
      // optional .usbguard.IPC.removeRuleResponse response = 3;
      {::_pbi::TcParser::FastMtS1,
       {26, 2, 2,
        PROTOBUF_FIELD_OFFSET(removeRule, _impl_.response_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required .usbguard.IPC.MessageHeader header = 1;
      {PROTOBUF_FIELD_OFFSET(removeRule, _impl_.header_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // required .usbguard.IPC.removeRuleRequest request = 2;
      {PROTOBUF_FIELD_OFFSET(removeRule, _impl_.request_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // optional .usbguard.IPC.removeRuleResponse response = 3;
      {PROTOBUF_FIELD_OFFSET(removeRule, _impl_.response_), _Internal::kHasBitsOffset + 2, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::MessageHeader>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::MessageHeader_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::removeRuleRequest>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::removeRuleRequest_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::removeRuleResponse>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::removeRuleResponse_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr removeRule::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : header_{nullptr},
        request_{nullptr},
        response_{nullptr} {}

template <typename>
constexpr removeRule::removeRule(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL removeRule::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) removeRule(arena);
}
constexpr auto removeRule::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(removeRule), alignof(removeRule));
}
constexpr auto removeRule::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          removeRule::IsInitializedImpl,
          &removeRule::MergeImpl,
          Super_::GetNewImpl<removeRule>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &removeRule::SharedDtor,
          Super_::GetClearImpl<removeRule>(), &removeRule::ByteSizeLong,
              &removeRule::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(removeRule, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[8],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct removeRuleGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr removeRuleGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 removeRule_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(removeRule::InternalGenerateClassData_(
            _default, &removeRule_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<removeRule>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~removeRuleGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) removeRule _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<removeRule>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(removeRuleGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST removeRuleGlobalsTypeInternal removeRule_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* removeRule_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return removeRule_globals_.GetClassData();
#else
  return removeRule_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class listRulesResponse::_Internal {
 public:
  using HasBits = decltype(::std::declval<listRulesResponse>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(listRulesResponse, _impl_._has_bits_);
};

constexpr listRulesResponse::ParseTableT_ listRulesResponse::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(listRulesResponse, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::listRulesResponse>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated .usbguard.IPC.Rule rules = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(listRulesResponse, _impl_.rules_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .usbguard.IPC.Rule rules = 1;
      {PROTOBUF_FIELD_OFFSET(listRulesResponse, _impl_.rules_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::Rule>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::Rule_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr listRulesResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : rules_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::usbguard::IPC::listRulesResponse,
            PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRulesResponse, _impl_.rules_)>()
         }
     {}

template <typename>
constexpr listRulesResponse::listRulesResponse(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL listRulesResponse::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) listRulesResponse(arena);
}
constexpr auto listRulesResponse::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(listRulesResponse), alignof(listRulesResponse));
}
constexpr auto listRulesResponse::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          listRulesResponse::IsInitializedImpl,
          &listRulesResponse::MergeImpl,
          Super_::GetNewImpl<listRulesResponse>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &listRulesResponse::SharedDtor,
          Super_::GetClearImpl<listRulesResponse>(), &listRulesResponse::ByteSizeLong,
              &listRulesResponse::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(listRulesResponse, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct listRulesResponseGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr listRulesResponseGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 listRulesResponse_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(listRulesResponse::InternalGenerateClassData_(
            _default, &listRulesResponse_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<listRulesResponse>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~listRulesResponseGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) listRulesResponse _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<listRulesResponse>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(listRulesResponseGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST listRulesResponseGlobalsTypeInternal listRulesResponse_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* listRulesResponse_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return listRulesResponse_globals_.GetClassData();
#else
  return listRulesResponse_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class checkIPCPermissions::_Internal {
 public:
  using HasBits = decltype(::std::declval<checkIPCPermissions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000003) ^ 0x00000003) != 0;
  }
};

constexpr checkIPCPermissions::ParseTableT_ checkIPCPermissions::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      3,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::checkIPCPermissions>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // required .usbguard.IPC.MessageHeader header = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.header_)}},
      // required .usbguard.IPC.checkIPCPermissionsRequest request = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 1, 1,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.request_)}},
      // optional .usbguard.IPC.checkIPCPermissionsResponse response = 3;
      {::_pbi::TcParser::FastMtS1,
       {26, 2, 2,
        PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.response_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required .usbguard.IPC.MessageHeader header = 1;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.header_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // required .usbguard.IPC.checkIPCPermissionsRequest request = 2;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.request_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // optional .usbguard.IPC.checkIPCPermissionsResponse response = 3;
      {PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.response_), _Internal::kHasBitsOffset + 2, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::MessageHeader>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::MessageHeader_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::checkIPCPermissionsRequest>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::checkIPCPermissionsRequest_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::checkIPCPermissionsResponse>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::checkIPCPermissionsResponse_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr checkIPCPermissions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : header_{nullptr},
        request_{nullptr},
        response_{nullptr} {}

template <typename>
constexpr checkIPCPermissions::checkIPCPermissions(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL checkIPCPermissions::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) checkIPCPermissions(arena);
}
constexpr auto checkIPCPermissions::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(checkIPCPermissions), alignof(checkIPCPermissions));
}
constexpr auto checkIPCPermissions::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          checkIPCPermissions::IsInitializedImpl,
          &checkIPCPermissions::MergeImpl,
          Super_::GetNewImpl<checkIPCPermissions>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &checkIPCPermissions::SharedDtor,
          Super_::GetClearImpl<checkIPCPermissions>(), &checkIPCPermissions::ByteSizeLong,
              &checkIPCPermissions::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[11],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct checkIPCPermissionsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr checkIPCPermissionsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 checkIPCPermissions_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(checkIPCPermissions::InternalGenerateClassData_(
            _default, &checkIPCPermissions_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<checkIPCPermissions>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~checkIPCPermissionsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) checkIPCPermissions _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<checkIPCPermissions>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(checkIPCPermissionsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST checkIPCPermissionsGlobalsTypeInternal checkIPCPermissions_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* checkIPCPermissions_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return checkIPCPermissions_globals_.GetClassData();
#else
  return checkIPCPermissions_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class appendRule::_Internal {
 public:
  using HasBits = decltype(::std::declval<appendRule>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(appendRule, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000003) ^ 0x00000003) != 0;
  }
};

constexpr appendRule::ParseTableT_ appendRule::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(appendRule, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      3,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::appendRule>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // required .usbguard.IPC.MessageHeader header = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(appendRule, _impl_.header_)}},
      // required .usbguard.IPC.appendRuleRequest request = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 1, 1,
        PROTOBUF_FIELD_OFFSET(appendRule, _impl_.request_)}},
      // optional .usbguard.IPC.appendRuleResponse response = 3;
      {::_pbi::TcParser::FastMtS1,
       {26, 2, 2,
        PROTOBUF_FIELD_OFFSET(appendRule, _impl_.response_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required .usbguard.IPC.MessageHeader header = 1;
      {PROTOBUF_FIELD_OFFSET(appendRule, _impl_.header_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // required .usbguard.IPC.appendRuleRequest request = 2;
      {PROTOBUF_FIELD_OFFSET(appendRule, _impl_.request_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // optional .usbguard.IPC.appendRuleResponse response = 3;
      {PROTOBUF_FIELD_OFFSET(appendRule, _impl_.response_), _Internal::kHasBitsOffset + 2, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::MessageHeader>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::MessageHeader_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::appendRuleRequest>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::appendRuleRequest_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::appendRuleResponse>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::appendRuleResponse_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr appendRule::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : header_{nullptr},
        request_{nullptr},
        response_{nullptr} {}

template <typename>
constexpr appendRule::appendRule(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL appendRule::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) appendRule(arena);
}
constexpr auto appendRule::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(appendRule), alignof(appendRule));
}
constexpr auto appendRule::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          appendRule::IsInitializedImpl,
          &appendRule::MergeImpl,
          Super_::GetNewImpl<appendRule>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &appendRule::SharedDtor,
          Super_::GetClearImpl<appendRule>(), &appendRule::ByteSizeLong,
              &appendRule::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(appendRule, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[5],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct appendRuleGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr appendRuleGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 appendRule_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(appendRule::InternalGenerateClassData_(
            _default, &appendRule_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<appendRule>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~appendRuleGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) appendRule _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<appendRule>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(appendRuleGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST appendRuleGlobalsTypeInternal appendRule_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* appendRule_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return appendRule_globals_.GetClassData();
#else
  return appendRule_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class listRules::_Internal {
 public:
  using HasBits = decltype(::std::declval<listRules>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(listRules, _impl_._has_bits_);
  static bool MissingRequiredFields(const HasBits& has_bits) {
    return ((has_bits[0] & 0x00000003) ^ 0x00000003) != 0;
  }
};

constexpr listRules::ParseTableT_ listRules::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(listRules, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      3,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::MpUnknownFields,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::usbguard::IPC::listRules>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // required .usbguard.IPC.MessageHeader header = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(listRules, _impl_.header_)}},
      // required .usbguard.IPC.listRulesRequest request = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 1, 1,
        PROTOBUF_FIELD_OFFSET(listRules, _impl_.request_)}},
      // optional .usbguard.IPC.listRulesResponse response = 3;
      {::_pbi::TcParser::FastMtS1,
       {26, 2, 2,
        PROTOBUF_FIELD_OFFSET(listRules, _impl_.response_)}},
    }}, {{
      65535, 65535
    }}, {{
      // required .usbguard.IPC.MessageHeader header = 1;
      {PROTOBUF_FIELD_OFFSET(listRules, _impl_.header_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // required .usbguard.IPC.listRulesRequest request = 2;
      {PROTOBUF_FIELD_OFFSET(listRules, _impl_.request_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // optional .usbguard.IPC.listRulesResponse response = 3;
      {PROTOBUF_FIELD_OFFSET(listRules, _impl_.response_), _Internal::kHasBitsOffset + 2, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::MessageHeader>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::MessageHeader_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::listRulesRequest>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::listRulesRequest_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::usbguard::IPC::listRulesResponse>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::usbguard::IPC::listRulesResponse_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr listRules::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : header_{nullptr},
        request_{nullptr},
        response_{nullptr} {}

template <typename>
constexpr listRules::listRules(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : Super_(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL listRules::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) listRules(arena);
}
constexpr auto listRules::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(listRules), alignof(listRules));
}
constexpr auto listRules::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          listRules::IsInitializedImpl,
          &listRules::MergeImpl,
          Super_::GetNewImpl<listRules>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &listRules::SharedDtor,
          Super_::GetClearImpl<listRules>(), &listRules::ByteSizeLong,
              &listRules::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(listRules, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_Policy_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct listRulesGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr listRulesGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 listRules_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(listRules::InternalGenerateClassData_(
            _default, &listRules_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<listRules>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~listRulesGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) listRules _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<listRules>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(listRulesGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST listRulesGlobalsTypeInternal listRules_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* listRules_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return listRules_globals_.GetClassData();
#else
  return listRules_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace IPC
}  // namespace usbguard
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_Policy_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_Policy_2eproto = nullptr;
const ::uint32_t
    TableStruct_Policy_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRulesRequest, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRulesRequest, _impl_.label_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRulesResponse, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRulesResponse, _impl_.rules_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRules, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRules, _impl_.header_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRules, _impl_.request_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRules, _impl_.response_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRuleRequest, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRuleRequest, _impl_.rule_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRuleRequest, _impl_.parent_id_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRuleRequest, _impl_.permanent_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRuleResponse, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRuleResponse, _impl_.id_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRule, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRule, _impl_.header_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRule, _impl_.request_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::appendRule, _impl_.response_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRuleRequest, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRuleRequest, _impl_.id_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRuleResponse, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRuleResponse, _impl_.id_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRule, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRule, _impl_.header_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRule, _impl_.request_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::removeRule, _impl_.response_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissionsRequest, _impl_._has_bits_),
        7, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissionsRequest, _impl_.uid_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissionsRequest, _impl_.gid_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissionsRequest, _impl_.section_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissionsRequest, _impl_.privilege_),
        2,
        3,
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissionsResponse, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissionsResponse, _impl_.permit_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissions, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissions, _impl_.header_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissions, _impl_.request_),
        PROTOBUF_FIELD_OFFSET(::usbguard::IPC::checkIPCPermissions, _impl_.response_),
        0,
        1,
        2,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::usbguard::IPC::listRulesRequest)},
        {5, sizeof(::usbguard::IPC::listRulesResponse)},
        {10, sizeof(::usbguard::IPC::listRules)},
        {19, sizeof(::usbguard::IPC::appendRuleRequest)},
        {28, sizeof(::usbguard::IPC::appendRuleResponse)},
        {33, sizeof(::usbguard::IPC::appendRule)},
        {42, sizeof(::usbguard::IPC::removeRuleRequest)},
        {47, sizeof(::usbguard::IPC::removeRuleResponse)},
        {52, sizeof(::usbguard::IPC::removeRule)},
        {61, sizeof(::usbguard::IPC::checkIPCPermissionsRequest)},
        {72, sizeof(::usbguard::IPC::checkIPCPermissionsResponse)},
        {77, sizeof(::usbguard::IPC::checkIPCPermissions)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::usbguard::IPC::listRulesRequest_globals_,
        &::usbguard::IPC::listRulesResponse_globals_,
        &::usbguard::IPC::listRules_globals_,
        &::usbguard::IPC::appendRuleRequest_globals_,
        &::usbguard::IPC::appendRuleResponse_globals_,
        &::usbguard::IPC::appendRule_globals_,
        &::usbguard::IPC::removeRuleRequest_globals_,
        &::usbguard::IPC::removeRuleResponse_globals_,
        &::usbguard::IPC::removeRule_globals_,
        &::usbguard::IPC::checkIPCPermissionsRequest_globals_,
        &::usbguard::IPC::checkIPCPermissionsResponse_globals_,
        &::usbguard::IPC::checkIPCPermissions_globals_,
};
const char descriptor_table_protodef_Policy_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\014Policy.proto\022\014usbguard.IPC\032\rMessage.pr"
    "oto\032\nRule.proto\"!\n\020listRulesRequest\022\r\n\005l"
    "abel\030\001 \002(\t\"6\n\021listRulesResponse\022!\n\005rules"
    "\030\001 \003(\0132\022.usbguard.IPC.Rule\"\234\001\n\tlistRules"
    "\022+\n\006header\030\001 \002(\0132\033.usbguard.IPC.MessageH"
    "eader\022/\n\007request\030\002 \002(\0132\036.usbguard.IPC.li"
    "stRulesRequest\0221\n\010response\030\003 \001(\0132\037.usbgu"
    "ard.IPC.listRulesResponse\"G\n\021appendRuleR"
    "equest\022\014\n\004rule\030\001 \002(\t\022\021\n\tparent_id\030\002 \002(\r\022"
    "\021\n\tpermanent\030\003 \002(\010\" \n\022appendRuleResponse"
    "\022\n\n\002id\030\001 \002(\r\"\237\001\n\nappendRule\022+\n\006header\030\001 "
    "\002(\0132\033.usbguard.IPC.MessageHeader\0220\n\007requ"
    "est\030\002 \002(\0132\037.usbguard.IPC.appendRuleReque"
    "st\0222\n\010response\030\003 \001(\0132 .usbguard.IPC.appe"
    "ndRuleResponse\"\037\n\021removeRuleRequest\022\n\n\002i"
    "d\030\001 \002(\r\" \n\022removeRuleResponse\022\n\n\002id\030\001 \002("
    "\r\"\237\001\n\nremoveRule\022+\n\006header\030\001 \002(\0132\033.usbgu"
    "ard.IPC.MessageHeader\0220\n\007request\030\002 \002(\0132\037"
    ".usbguard.IPC.removeRuleRequest\0222\n\010respo"
    "nse\030\003 \001(\0132 .usbguard.IPC.removeRuleRespo"
    "nse\"Z\n\032checkIPCPermissionsRequest\022\013\n\003uid"
    "\030\001 \002(\r\022\013\n\003gid\030\002 \002(\r\022\017\n\007section\030\003 \002(\t\022\021\n\t"
    "privilege\030\004 \002(\t\"-\n\033checkIPCPermissionsRe"
    "sponse\022\016\n\006permit\030\001 \002(\010\"\272\001\n\023checkIPCPermi"
    "ssions\022+\n\006header\030\001 \002(\0132\033.usbguard.IPC.Me"
    "ssageHeader\0229\n\007request\030\002 \002(\0132(.usbguard."
    "IPC.checkIPCPermissionsRequest\022;\n\010respon"
    "se\030\003 \001(\0132).usbguard.IPC.checkIPCPermissi"
    "onsResponse"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_Policy_2eproto_deps[2] = {
        &::descriptor_table_Message_2eproto,
        &::descriptor_table_Rule_2eproto,
};
static ::absl::once_flag descriptor_table_Policy_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_Policy_2eproto = {
    false,
    false,
    1131,
    descriptor_table_protodef_Policy_2eproto,
    "Policy.proto",
    &descriptor_table_Policy_2eproto_once,
    descriptor_table_Policy_2eproto_deps,
    2,
    12,
    schemas,
    file_message_globals,
    TableStruct_Policy_2eproto::offsets,
    file_level_enum_descriptors_Policy_2eproto,
    file_level_service_descriptors_Policy_2eproto,
};
namespace usbguard {
namespace IPC {
// ===================================================================

listRulesRequest::listRulesRequest(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, listRulesRequest_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.listRulesRequest)
}
PROTOBUF_NDEBUG_INLINE listRulesRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::listRulesRequest& from_msg)
      : _has_bits_{from._has_bits_},
        label_(arena, from.label_) {}

listRulesRequest::listRulesRequest(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const listRulesRequest& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, listRulesRequest_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  listRulesRequest* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.listRulesRequest)
}
PROTOBUF_NDEBUG_INLINE listRulesRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : label_(arena) {}

inline void listRulesRequest::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
listRulesRequest::~listRulesRequest() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.listRulesRequest)
  SharedDtor(*this);
}
inline void listRulesRequest::SharedDtor(MessageLite& self) {
  listRulesRequest& this_ = static_cast<listRulesRequest&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.label_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull listRulesRequest_class_data_ =
        listRulesRequest::InternalGenerateClassData_(listRulesRequest_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
listRulesRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&listRulesRequest_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(listRulesRequest_class_data_.tc_table);
  return listRulesRequest_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
listRulesRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&listRulesRequest_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&listRulesRequest_globals_));
  return listRulesRequest_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const listRulesRequest::ParseTableT_
    listRulesRequest::_table_ =
        listRulesRequest::InternalGenerateParseTable_(listRulesRequest_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void listRulesRequest::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.listRulesRequest)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    this_._impl_.label_.ClearNonDefaultToEmpty();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL listRulesRequest::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const listRulesRequest& this_ = static_cast<const listRulesRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL listRulesRequest::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const listRulesRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.listRulesRequest)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required string label = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    const ::std::string& _s = this_._internal_label();
    target = stream->WriteStringMaybeAliased(1, _s, target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.listRulesRequest)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t listRulesRequest::ByteSizeLong(const MessageLite& base) {
  const listRulesRequest& this_ = static_cast<const listRulesRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t listRulesRequest::ByteSizeLong() const {
  const listRulesRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.listRulesRequest)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

   {
    // required string label = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_label());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void listRulesRequest::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<listRulesRequest*>(&to_msg);
  auto& from = static_cast<const listRulesRequest&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.listRulesRequest)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_set_label(from._internal_label());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void listRulesRequest::CopyFrom(const listRulesRequest& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.listRulesRequest)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool listRulesRequest::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const listRulesRequest&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void listRulesRequest::InternalSwap(listRulesRequest* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.label_, &other->_impl_.label_, arena);
}

::google::protobuf::Metadata listRulesRequest::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void listRulesResponse::clear_rules() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.rules_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
listRulesResponse::listRulesResponse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, listRulesResponse_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.listRulesResponse)
}
PROTOBUF_NDEBUG_INLINE listRulesResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::listRulesResponse& from_msg)
      : _has_bits_{from._has_bits_},
        rules_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::usbguard::IPC::listRulesResponse,
              PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRulesResponse, _impl_.rules_)>()
          , arena, from.rules_
        }
     {}

listRulesResponse::listRulesResponse(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const listRulesResponse& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, listRulesResponse_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  listRulesResponse* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.listRulesResponse)
}
PROTOBUF_NDEBUG_INLINE listRulesResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : rules_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::usbguard::IPC::listRulesResponse,
            PROTOBUF_FIELD_OFFSET(::usbguard::IPC::listRulesResponse, _impl_.rules_)>()
         }
     {}

inline void listRulesResponse::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
listRulesResponse::~listRulesResponse() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.listRulesResponse)
  SharedDtor(*this);
}
inline void listRulesResponse::SharedDtor(MessageLite& self) {
  listRulesResponse& this_ = static_cast<listRulesResponse&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull listRulesResponse_class_data_ =
        listRulesResponse::InternalGenerateClassData_(listRulesResponse_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
listRulesResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&listRulesResponse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(listRulesResponse_class_data_.tc_table);
  return listRulesResponse_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
listRulesResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&listRulesResponse_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&listRulesResponse_globals_));
  return listRulesResponse_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const listRulesResponse::ParseTableT_
    listRulesResponse::_table_ =
        listRulesResponse::InternalGenerateParseTable_(listRulesResponse_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void listRulesResponse::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.listRulesResponse)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.rules_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL listRulesResponse::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const listRulesResponse& this_ = static_cast<const listRulesResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL listRulesResponse::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const listRulesResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.listRulesResponse)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .usbguard.IPC.Rule rules = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_rules_size());
         i < n; i++) {
      const auto& repfield = this_._internal_rules().Get(i);
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          1, repfield, repfield.GetCachedSize(), target,
          stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.listRulesResponse)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t listRulesResponse::ByteSizeLong(const MessageLite& base) {
  const listRulesResponse& this_ = static_cast<const listRulesResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t listRulesResponse::ByteSizeLong() const {
  const listRulesResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.listRulesResponse)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .usbguard.IPC.Rule rules = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_rules_size();
      for (const auto& msg : this_._internal_rules()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void listRulesResponse::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<listRulesResponse*>(&to_msg);
  auto& from = static_cast<const listRulesResponse&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.listRulesResponse)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_rules()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_rules());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void listRulesResponse::CopyFrom(const listRulesResponse& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.listRulesResponse)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool listRulesResponse::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const listRulesResponse&>(msg);
  if (!::google::protobuf::internal::AllAreInitialized(this_._internal_rules()))
    return false;
  return true;
}

void listRulesResponse::InternalSwap(listRulesResponse* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.rules_.InternalSwap(&other->_impl_.rules_);
}

::google::protobuf::Metadata listRulesResponse::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void listRules::clear_header() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.header_ != nullptr) _impl_.header_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
listRules::listRules(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, listRules_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.listRules)
}
PROTOBUF_NDEBUG_INLINE listRules::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::listRules& from_msg)
      : _has_bits_{from._has_bits_} {}

listRules::listRules(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const listRules& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, listRules_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  listRules* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.header_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                 ? Super_::CopyConstruct(arena, *from._impl_.header_)
                 : nullptr;
  _impl_.request_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                 ? Super_::CopyConstruct(arena, *from._impl_.request_)
                 : nullptr;
  _impl_.response_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                 ? Super_::CopyConstruct(arena, *from._impl_.response_)
                 : nullptr;

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.listRules)
}
PROTOBUF_NDEBUG_INLINE listRules::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void listRules::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, header_),
           0,
           offsetof(Impl_, response_) -
               offsetof(Impl_, header_) +
               sizeof(Impl_::response_));
}
listRules::~listRules() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.listRules)
  SharedDtor(*this);
}
inline void listRules::SharedDtor(MessageLite& self) {
  listRules& this_ = static_cast<listRules&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.header_;
  delete this_._impl_.request_;
  delete this_._impl_.response_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull listRules_class_data_ =
        listRules::InternalGenerateClassData_(listRules_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
listRules::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&listRules_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(listRules_class_data_.tc_table);
  return listRules_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
listRules::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&listRules_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&listRules_globals_));
  return listRules_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const listRules::ParseTableT_
    listRules::_table_ =
        listRules::InternalGenerateParseTable_(listRules_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void listRules::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.listRules)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(this_._impl_.header_ != nullptr);
      this_._impl_.header_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(this_._impl_.request_ != nullptr);
      this_._impl_.request_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(this_._impl_.response_ != nullptr);
      this_._impl_.response_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL listRules::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const listRules& this_ = static_cast<const listRules&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL listRules::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const listRules& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.listRules)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required .usbguard.IPC.MessageHeader header = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.header_, this_._impl_.header_->GetCachedSize(), target,
        stream);
  }

  // required .usbguard.IPC.listRulesRequest request = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.request_, this_._impl_.request_->GetCachedSize(), target,
        stream);
  }

  // optional .usbguard.IPC.listRulesResponse response = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        3, *this_._impl_.response_, this_._impl_.response_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.listRules)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t listRules::ByteSizeLong(const MessageLite& base) {
  const listRules& this_ = static_cast<const listRules&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t listRules::ByteSizeLong() const {
  const listRules& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.listRules)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // required .usbguard.IPC.MessageHeader header = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.header_);
    }
    // required .usbguard.IPC.listRulesRequest request = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.request_);
    }
  }
   {
    // optional .usbguard.IPC.listRulesResponse response = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.response_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void listRules::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<listRules*>(&to_msg);
  auto& from = static_cast<const listRules&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.listRules)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.header_ != nullptr);
      if (_this->_impl_.header_ == nullptr) {
        _this->_impl_.header_ = Super_::CopyConstruct(arena, *from._impl_.header_);
      } else {
        _this->_impl_.header_->MergeFrom(*from._impl_.header_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.request_ != nullptr);
      if (_this->_impl_.request_ == nullptr) {
        _this->_impl_.request_ = Super_::CopyConstruct(arena, *from._impl_.request_);
      } else {
        _this->_impl_.request_->MergeFrom(*from._impl_.request_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.response_ != nullptr);
      if (_this->_impl_.response_ == nullptr) {
        _this->_impl_.response_ = Super_::CopyConstruct(arena, *from._impl_.response_);
      } else {
        _this->_impl_.response_->MergeFrom(*from._impl_.response_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void listRules::CopyFrom(const listRules& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.listRules)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool listRules::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const listRules&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000001U)) {
    if (!this_._impl_.header_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000002U)) {
    if (!this_._impl_.request_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000004U)) {
    if (!this_._impl_.response_->IsInitialized()) return false;
  }
  return true;
}

void listRules::InternalSwap(listRules* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(listRules, _impl_.response_)
      + sizeof(listRules::_impl_.response_)
      - PROTOBUF_FIELD_OFFSET(listRules, _impl_.header_)>(
          reinterpret_cast<char*>(&_impl_.header_),
          reinterpret_cast<char*>(&other->_impl_.header_));
}

::google::protobuf::Metadata listRules::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

appendRuleRequest::appendRuleRequest(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, appendRuleRequest_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.appendRuleRequest)
}
PROTOBUF_NDEBUG_INLINE appendRuleRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::appendRuleRequest& from_msg)
      : _has_bits_{from._has_bits_},
        rule_(arena, from.rule_) {}

appendRuleRequest::appendRuleRequest(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const appendRuleRequest& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, appendRuleRequest_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  appendRuleRequest* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, parent_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, parent_id_),
           offsetof(Impl_, permanent_) -
               offsetof(Impl_, parent_id_) +
               sizeof(Impl_::permanent_));

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.appendRuleRequest)
}
PROTOBUF_NDEBUG_INLINE appendRuleRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : rule_(arena) {}

inline void appendRuleRequest::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, parent_id_),
           0,
           offsetof(Impl_, permanent_) -
               offsetof(Impl_, parent_id_) +
               sizeof(Impl_::permanent_));
}
appendRuleRequest::~appendRuleRequest() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.appendRuleRequest)
  SharedDtor(*this);
}
inline void appendRuleRequest::SharedDtor(MessageLite& self) {
  appendRuleRequest& this_ = static_cast<appendRuleRequest&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.rule_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull appendRuleRequest_class_data_ =
        appendRuleRequest::InternalGenerateClassData_(appendRuleRequest_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
appendRuleRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&appendRuleRequest_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(appendRuleRequest_class_data_.tc_table);
  return appendRuleRequest_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
appendRuleRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&appendRuleRequest_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&appendRuleRequest_globals_));
  return appendRuleRequest_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const appendRuleRequest::ParseTableT_
    appendRuleRequest::_table_ =
        appendRuleRequest::InternalGenerateParseTable_(appendRuleRequest_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void appendRuleRequest::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.appendRuleRequest)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    this_._impl_.rule_.ClearNonDefaultToEmpty();
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000006U)) {
    ::memset(&this_._impl_.parent_id_, 0,
             static_cast<::size_t>(
                 reinterpret_cast<char*>(&this_._impl_.permanent_) -
                 reinterpret_cast<char*>(&this_._impl_.parent_id_)) +
                 sizeof(_impl_.permanent_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL appendRuleRequest::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const appendRuleRequest& this_ = static_cast<const appendRuleRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL appendRuleRequest::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const appendRuleRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.appendRuleRequest)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required string rule = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    const ::std::string& _s = this_._internal_rule();
    target = stream->WriteStringMaybeAliased(1, _s, target);
  }

  // required uint32 parent_id = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
        2, this_._internal_parent_id(), target);
  }

  // required bool permanent = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        3, this_._internal_permanent(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.appendRuleRequest)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t appendRuleRequest::ByteSizeLong(const MessageLite& base) {
  const appendRuleRequest& this_ = static_cast<const appendRuleRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t appendRuleRequest::ByteSizeLong() const {
  const appendRuleRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.appendRuleRequest)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += static_cast<bool>(0x00000004U & cached_has_bits) * 2;
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // required string rule = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_rule());
    }
    // required uint32 parent_id = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
          this_._internal_parent_id());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void appendRuleRequest::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<appendRuleRequest*>(&to_msg);
  auto& from = static_cast<const appendRuleRequest&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.appendRuleRequest)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_set_rule(from._internal_rule());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_impl_.parent_id_ = from._impl_.parent_id_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.permanent_ = from._impl_.permanent_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void appendRuleRequest::CopyFrom(const appendRuleRequest& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.appendRuleRequest)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool appendRuleRequest::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const appendRuleRequest&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void appendRuleRequest::InternalSwap(appendRuleRequest* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.rule_, &other->_impl_.rule_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.permanent_)
      + sizeof(appendRuleRequest::_impl_.permanent_)
      - PROTOBUF_FIELD_OFFSET(appendRuleRequest, _impl_.parent_id_)>(
          reinterpret_cast<char*>(&_impl_.parent_id_),
          reinterpret_cast<char*>(&other->_impl_.parent_id_));
}

::google::protobuf::Metadata appendRuleRequest::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

appendRuleResponse::appendRuleResponse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, appendRuleResponse_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.appendRuleResponse)
}
appendRuleResponse::appendRuleResponse(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const appendRuleResponse& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, appendRuleResponse_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE appendRuleResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void appendRuleResponse::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.id_ = {};
}
appendRuleResponse::~appendRuleResponse() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.appendRuleResponse)
  SharedDtor(*this);
}
inline void appendRuleResponse::SharedDtor(MessageLite& self) {
  appendRuleResponse& this_ = static_cast<appendRuleResponse&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull appendRuleResponse_class_data_ =
        appendRuleResponse::InternalGenerateClassData_(appendRuleResponse_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
appendRuleResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&appendRuleResponse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(appendRuleResponse_class_data_.tc_table);
  return appendRuleResponse_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
appendRuleResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&appendRuleResponse_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&appendRuleResponse_globals_));
  return appendRuleResponse_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const appendRuleResponse::ParseTableT_
    appendRuleResponse::_table_ =
        appendRuleResponse::InternalGenerateParseTable_(appendRuleResponse_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void appendRuleResponse::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.appendRuleResponse)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  this_._impl_.id_ = 0u;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL appendRuleResponse::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const appendRuleResponse& this_ = static_cast<const appendRuleResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL appendRuleResponse::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const appendRuleResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.appendRuleResponse)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required uint32 id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
        1, this_._internal_id(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.appendRuleResponse)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t appendRuleResponse::ByteSizeLong(const MessageLite& base) {
  const appendRuleResponse& this_ = static_cast<const appendRuleResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t appendRuleResponse::ByteSizeLong() const {
  const appendRuleResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.appendRuleResponse)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

   {
    // required uint32 id = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
          this_._internal_id());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void appendRuleResponse::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<appendRuleResponse*>(&to_msg);
  auto& from = static_cast<const appendRuleResponse&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.appendRuleResponse)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_impl_.id_ = from._impl_.id_;
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void appendRuleResponse::CopyFrom(const appendRuleResponse& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.appendRuleResponse)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool appendRuleResponse::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const appendRuleResponse&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void appendRuleResponse::InternalSwap(appendRuleResponse* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.id_, other->_impl_.id_);
}

::google::protobuf::Metadata appendRuleResponse::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void appendRule::clear_header() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.header_ != nullptr) _impl_.header_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
appendRule::appendRule(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, appendRule_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.appendRule)
}
PROTOBUF_NDEBUG_INLINE appendRule::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::appendRule& from_msg)
      : _has_bits_{from._has_bits_} {}

appendRule::appendRule(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const appendRule& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, appendRule_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  appendRule* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.header_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                 ? Super_::CopyConstruct(arena, *from._impl_.header_)
                 : nullptr;
  _impl_.request_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                 ? Super_::CopyConstruct(arena, *from._impl_.request_)
                 : nullptr;
  _impl_.response_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                 ? Super_::CopyConstruct(arena, *from._impl_.response_)
                 : nullptr;

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.appendRule)
}
PROTOBUF_NDEBUG_INLINE appendRule::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void appendRule::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, header_),
           0,
           offsetof(Impl_, response_) -
               offsetof(Impl_, header_) +
               sizeof(Impl_::response_));
}
appendRule::~appendRule() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.appendRule)
  SharedDtor(*this);
}
inline void appendRule::SharedDtor(MessageLite& self) {
  appendRule& this_ = static_cast<appendRule&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.header_;
  delete this_._impl_.request_;
  delete this_._impl_.response_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull appendRule_class_data_ =
        appendRule::InternalGenerateClassData_(appendRule_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
appendRule::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&appendRule_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(appendRule_class_data_.tc_table);
  return appendRule_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
appendRule::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&appendRule_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&appendRule_globals_));
  return appendRule_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const appendRule::ParseTableT_
    appendRule::_table_ =
        appendRule::InternalGenerateParseTable_(appendRule_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void appendRule::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.appendRule)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(this_._impl_.header_ != nullptr);
      this_._impl_.header_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(this_._impl_.request_ != nullptr);
      this_._impl_.request_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(this_._impl_.response_ != nullptr);
      this_._impl_.response_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL appendRule::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const appendRule& this_ = static_cast<const appendRule&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL appendRule::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const appendRule& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.appendRule)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required .usbguard.IPC.MessageHeader header = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.header_, this_._impl_.header_->GetCachedSize(), target,
        stream);
  }

  // required .usbguard.IPC.appendRuleRequest request = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.request_, this_._impl_.request_->GetCachedSize(), target,
        stream);
  }

  // optional .usbguard.IPC.appendRuleResponse response = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        3, *this_._impl_.response_, this_._impl_.response_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.appendRule)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t appendRule::ByteSizeLong(const MessageLite& base) {
  const appendRule& this_ = static_cast<const appendRule&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t appendRule::ByteSizeLong() const {
  const appendRule& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.appendRule)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // required .usbguard.IPC.MessageHeader header = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.header_);
    }
    // required .usbguard.IPC.appendRuleRequest request = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.request_);
    }
  }
   {
    // optional .usbguard.IPC.appendRuleResponse response = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.response_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void appendRule::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<appendRule*>(&to_msg);
  auto& from = static_cast<const appendRule&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.appendRule)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.header_ != nullptr);
      if (_this->_impl_.header_ == nullptr) {
        _this->_impl_.header_ = Super_::CopyConstruct(arena, *from._impl_.header_);
      } else {
        _this->_impl_.header_->MergeFrom(*from._impl_.header_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.request_ != nullptr);
      if (_this->_impl_.request_ == nullptr) {
        _this->_impl_.request_ = Super_::CopyConstruct(arena, *from._impl_.request_);
      } else {
        _this->_impl_.request_->MergeFrom(*from._impl_.request_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.response_ != nullptr);
      if (_this->_impl_.response_ == nullptr) {
        _this->_impl_.response_ = Super_::CopyConstruct(arena, *from._impl_.response_);
      } else {
        _this->_impl_.response_->MergeFrom(*from._impl_.response_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void appendRule::CopyFrom(const appendRule& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.appendRule)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool appendRule::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const appendRule&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000001U)) {
    if (!this_._impl_.header_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000002U)) {
    if (!this_._impl_.request_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000004U)) {
    if (!this_._impl_.response_->IsInitialized()) return false;
  }
  return true;
}

void appendRule::InternalSwap(appendRule* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(appendRule, _impl_.response_)
      + sizeof(appendRule::_impl_.response_)
      - PROTOBUF_FIELD_OFFSET(appendRule, _impl_.header_)>(
          reinterpret_cast<char*>(&_impl_.header_),
          reinterpret_cast<char*>(&other->_impl_.header_));
}

::google::protobuf::Metadata appendRule::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

removeRuleRequest::removeRuleRequest(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, removeRuleRequest_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.removeRuleRequest)
}
removeRuleRequest::removeRuleRequest(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const removeRuleRequest& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, removeRuleRequest_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE removeRuleRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void removeRuleRequest::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.id_ = {};
}
removeRuleRequest::~removeRuleRequest() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.removeRuleRequest)
  SharedDtor(*this);
}
inline void removeRuleRequest::SharedDtor(MessageLite& self) {
  removeRuleRequest& this_ = static_cast<removeRuleRequest&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull removeRuleRequest_class_data_ =
        removeRuleRequest::InternalGenerateClassData_(removeRuleRequest_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
removeRuleRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&removeRuleRequest_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(removeRuleRequest_class_data_.tc_table);
  return removeRuleRequest_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
removeRuleRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&removeRuleRequest_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&removeRuleRequest_globals_));
  return removeRuleRequest_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const removeRuleRequest::ParseTableT_
    removeRuleRequest::_table_ =
        removeRuleRequest::InternalGenerateParseTable_(removeRuleRequest_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void removeRuleRequest::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.removeRuleRequest)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  this_._impl_.id_ = 0u;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL removeRuleRequest::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const removeRuleRequest& this_ = static_cast<const removeRuleRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL removeRuleRequest::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const removeRuleRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.removeRuleRequest)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required uint32 id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
        1, this_._internal_id(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.removeRuleRequest)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t removeRuleRequest::ByteSizeLong(const MessageLite& base) {
  const removeRuleRequest& this_ = static_cast<const removeRuleRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t removeRuleRequest::ByteSizeLong() const {
  const removeRuleRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.removeRuleRequest)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

   {
    // required uint32 id = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
          this_._internal_id());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void removeRuleRequest::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<removeRuleRequest*>(&to_msg);
  auto& from = static_cast<const removeRuleRequest&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.removeRuleRequest)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_impl_.id_ = from._impl_.id_;
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void removeRuleRequest::CopyFrom(const removeRuleRequest& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.removeRuleRequest)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool removeRuleRequest::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const removeRuleRequest&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void removeRuleRequest::InternalSwap(removeRuleRequest* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.id_, other->_impl_.id_);
}

::google::protobuf::Metadata removeRuleRequest::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

removeRuleResponse::removeRuleResponse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, removeRuleResponse_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.removeRuleResponse)
}
removeRuleResponse::removeRuleResponse(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const removeRuleResponse& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, removeRuleResponse_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE removeRuleResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void removeRuleResponse::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.id_ = {};
}
removeRuleResponse::~removeRuleResponse() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.removeRuleResponse)
  SharedDtor(*this);
}
inline void removeRuleResponse::SharedDtor(MessageLite& self) {
  removeRuleResponse& this_ = static_cast<removeRuleResponse&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull removeRuleResponse_class_data_ =
        removeRuleResponse::InternalGenerateClassData_(removeRuleResponse_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
removeRuleResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&removeRuleResponse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(removeRuleResponse_class_data_.tc_table);
  return removeRuleResponse_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
removeRuleResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&removeRuleResponse_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&removeRuleResponse_globals_));
  return removeRuleResponse_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const removeRuleResponse::ParseTableT_
    removeRuleResponse::_table_ =
        removeRuleResponse::InternalGenerateParseTable_(removeRuleResponse_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void removeRuleResponse::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.removeRuleResponse)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  this_._impl_.id_ = 0u;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL removeRuleResponse::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const removeRuleResponse& this_ = static_cast<const removeRuleResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL removeRuleResponse::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const removeRuleResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.removeRuleResponse)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required uint32 id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
        1, this_._internal_id(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.removeRuleResponse)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t removeRuleResponse::ByteSizeLong(const MessageLite& base) {
  const removeRuleResponse& this_ = static_cast<const removeRuleResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t removeRuleResponse::ByteSizeLong() const {
  const removeRuleResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.removeRuleResponse)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

   {
    // required uint32 id = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
          this_._internal_id());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void removeRuleResponse::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<removeRuleResponse*>(&to_msg);
  auto& from = static_cast<const removeRuleResponse&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.removeRuleResponse)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_impl_.id_ = from._impl_.id_;
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void removeRuleResponse::CopyFrom(const removeRuleResponse& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.removeRuleResponse)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool removeRuleResponse::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const removeRuleResponse&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void removeRuleResponse::InternalSwap(removeRuleResponse* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.id_, other->_impl_.id_);
}

::google::protobuf::Metadata removeRuleResponse::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void removeRule::clear_header() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.header_ != nullptr) _impl_.header_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
removeRule::removeRule(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, removeRule_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.removeRule)
}
PROTOBUF_NDEBUG_INLINE removeRule::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::removeRule& from_msg)
      : _has_bits_{from._has_bits_} {}

removeRule::removeRule(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const removeRule& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, removeRule_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  removeRule* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.header_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                 ? Super_::CopyConstruct(arena, *from._impl_.header_)
                 : nullptr;
  _impl_.request_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                 ? Super_::CopyConstruct(arena, *from._impl_.request_)
                 : nullptr;
  _impl_.response_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                 ? Super_::CopyConstruct(arena, *from._impl_.response_)
                 : nullptr;

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.removeRule)
}
PROTOBUF_NDEBUG_INLINE removeRule::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void removeRule::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, header_),
           0,
           offsetof(Impl_, response_) -
               offsetof(Impl_, header_) +
               sizeof(Impl_::response_));
}
removeRule::~removeRule() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.removeRule)
  SharedDtor(*this);
}
inline void removeRule::SharedDtor(MessageLite& self) {
  removeRule& this_ = static_cast<removeRule&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.header_;
  delete this_._impl_.request_;
  delete this_._impl_.response_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull removeRule_class_data_ =
        removeRule::InternalGenerateClassData_(removeRule_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
removeRule::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&removeRule_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(removeRule_class_data_.tc_table);
  return removeRule_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
removeRule::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&removeRule_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&removeRule_globals_));
  return removeRule_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const removeRule::ParseTableT_
    removeRule::_table_ =
        removeRule::InternalGenerateParseTable_(removeRule_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void removeRule::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.removeRule)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(this_._impl_.header_ != nullptr);
      this_._impl_.header_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(this_._impl_.request_ != nullptr);
      this_._impl_.request_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(this_._impl_.response_ != nullptr);
      this_._impl_.response_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL removeRule::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const removeRule& this_ = static_cast<const removeRule&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL removeRule::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const removeRule& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.removeRule)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required .usbguard.IPC.MessageHeader header = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.header_, this_._impl_.header_->GetCachedSize(), target,
        stream);
  }

  // required .usbguard.IPC.removeRuleRequest request = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.request_, this_._impl_.request_->GetCachedSize(), target,
        stream);
  }

  // optional .usbguard.IPC.removeRuleResponse response = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        3, *this_._impl_.response_, this_._impl_.response_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.removeRule)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t removeRule::ByteSizeLong(const MessageLite& base) {
  const removeRule& this_ = static_cast<const removeRule&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t removeRule::ByteSizeLong() const {
  const removeRule& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.removeRule)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // required .usbguard.IPC.MessageHeader header = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.header_);
    }
    // required .usbguard.IPC.removeRuleRequest request = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.request_);
    }
  }
   {
    // optional .usbguard.IPC.removeRuleResponse response = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.response_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void removeRule::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<removeRule*>(&to_msg);
  auto& from = static_cast<const removeRule&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.removeRule)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.header_ != nullptr);
      if (_this->_impl_.header_ == nullptr) {
        _this->_impl_.header_ = Super_::CopyConstruct(arena, *from._impl_.header_);
      } else {
        _this->_impl_.header_->MergeFrom(*from._impl_.header_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.request_ != nullptr);
      if (_this->_impl_.request_ == nullptr) {
        _this->_impl_.request_ = Super_::CopyConstruct(arena, *from._impl_.request_);
      } else {
        _this->_impl_.request_->MergeFrom(*from._impl_.request_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.response_ != nullptr);
      if (_this->_impl_.response_ == nullptr) {
        _this->_impl_.response_ = Super_::CopyConstruct(arena, *from._impl_.response_);
      } else {
        _this->_impl_.response_->MergeFrom(*from._impl_.response_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void removeRule::CopyFrom(const removeRule& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.removeRule)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool removeRule::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const removeRule&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000001U)) {
    if (!this_._impl_.header_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000002U)) {
    if (!this_._impl_.request_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000004U)) {
    if (!this_._impl_.response_->IsInitialized()) return false;
  }
  return true;
}

void removeRule::InternalSwap(removeRule* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(removeRule, _impl_.response_)
      + sizeof(removeRule::_impl_.response_)
      - PROTOBUF_FIELD_OFFSET(removeRule, _impl_.header_)>(
          reinterpret_cast<char*>(&_impl_.header_),
          reinterpret_cast<char*>(&other->_impl_.header_));
}

::google::protobuf::Metadata removeRule::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

checkIPCPermissionsRequest::checkIPCPermissionsRequest(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, checkIPCPermissionsRequest_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.checkIPCPermissionsRequest)
}
PROTOBUF_NDEBUG_INLINE checkIPCPermissionsRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::checkIPCPermissionsRequest& from_msg)
      : _has_bits_{from._has_bits_},
        section_(arena, from.section_),
        privilege_(arena, from.privilege_) {}

checkIPCPermissionsRequest::checkIPCPermissionsRequest(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const checkIPCPermissionsRequest& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, checkIPCPermissionsRequest_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  checkIPCPermissionsRequest* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, uid_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, uid_),
           offsetof(Impl_, gid_) -
               offsetof(Impl_, uid_) +
               sizeof(Impl_::gid_));

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.checkIPCPermissionsRequest)
}
PROTOBUF_NDEBUG_INLINE checkIPCPermissionsRequest::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : section_(arena),
        privilege_(arena) {}

inline void checkIPCPermissionsRequest::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, uid_),
           0,
           offsetof(Impl_, gid_) -
               offsetof(Impl_, uid_) +
               sizeof(Impl_::gid_));
}
checkIPCPermissionsRequest::~checkIPCPermissionsRequest() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.checkIPCPermissionsRequest)
  SharedDtor(*this);
}
inline void checkIPCPermissionsRequest::SharedDtor(MessageLite& self) {
  checkIPCPermissionsRequest& this_ = static_cast<checkIPCPermissionsRequest&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.section_.Destroy();
  this_._impl_.privilege_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull checkIPCPermissionsRequest_class_data_ =
        checkIPCPermissionsRequest::InternalGenerateClassData_(checkIPCPermissionsRequest_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
checkIPCPermissionsRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&checkIPCPermissionsRequest_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(checkIPCPermissionsRequest_class_data_.tc_table);
  return checkIPCPermissionsRequest_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
checkIPCPermissionsRequest::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&checkIPCPermissionsRequest_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&checkIPCPermissionsRequest_globals_));
  return checkIPCPermissionsRequest_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const checkIPCPermissionsRequest::ParseTableT_
    checkIPCPermissionsRequest::_table_ =
        checkIPCPermissionsRequest::InternalGenerateParseTable_(checkIPCPermissionsRequest_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void checkIPCPermissionsRequest::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.checkIPCPermissionsRequest)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      this_._impl_.section_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      this_._impl_.privilege_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000000cU)) {
    ::memset(&this_._impl_.uid_, 0,
             static_cast<::size_t>(
                 reinterpret_cast<char*>(&this_._impl_.gid_) -
                 reinterpret_cast<char*>(&this_._impl_.uid_)) +
                 sizeof(_impl_.gid_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL checkIPCPermissionsRequest::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const checkIPCPermissionsRequest& this_ = static_cast<const checkIPCPermissionsRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL checkIPCPermissionsRequest::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const checkIPCPermissionsRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.checkIPCPermissionsRequest)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required uint32 uid = 1;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
        1, this_._internal_uid(), target);
  }

  // required uint32 gid = 2;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
        2, this_._internal_gid(), target);
  }

  // required string section = 3;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    const ::std::string& _s = this_._internal_section();
    target = stream->WriteStringMaybeAliased(3, _s, target);
  }

  // required string privilege = 4;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    const ::std::string& _s = this_._internal_privilege();
    target = stream->WriteStringMaybeAliased(4, _s, target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.checkIPCPermissionsRequest)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t checkIPCPermissionsRequest::ByteSizeLong(const MessageLite& base) {
  const checkIPCPermissionsRequest& this_ = static_cast<const checkIPCPermissionsRequest&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t checkIPCPermissionsRequest::ByteSizeLong() const {
  const checkIPCPermissionsRequest& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.checkIPCPermissionsRequest)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    // required string section = 3;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_section());
    }
    // required string privilege = 4;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_privilege());
    }
    // required uint32 uid = 1;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
          this_._internal_uid());
    }
    // required uint32 gid = 2;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
          this_._internal_gid());
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void checkIPCPermissionsRequest::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<checkIPCPermissionsRequest*>(&to_msg);
  auto& from = static_cast<const checkIPCPermissionsRequest&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.checkIPCPermissionsRequest)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000000fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_set_section(from._internal_section());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_set_privilege(from._internal_privilege());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.uid_ = from._impl_.uid_;
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _this->_impl_.gid_ = from._impl_.gid_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void checkIPCPermissionsRequest::CopyFrom(const checkIPCPermissionsRequest& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.checkIPCPermissionsRequest)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool checkIPCPermissionsRequest::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const checkIPCPermissionsRequest&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void checkIPCPermissionsRequest::InternalSwap(checkIPCPermissionsRequest* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.section_, &other->_impl_.section_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.privilege_, &other->_impl_.privilege_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.gid_)
      + sizeof(checkIPCPermissionsRequest::_impl_.gid_)
      - PROTOBUF_FIELD_OFFSET(checkIPCPermissionsRequest, _impl_.uid_)>(
          reinterpret_cast<char*>(&_impl_.uid_),
          reinterpret_cast<char*>(&other->_impl_.uid_));
}

::google::protobuf::Metadata checkIPCPermissionsRequest::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

checkIPCPermissionsResponse::checkIPCPermissionsResponse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, checkIPCPermissionsResponse_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.checkIPCPermissionsResponse)
}
checkIPCPermissionsResponse::checkIPCPermissionsResponse(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const checkIPCPermissionsResponse& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, checkIPCPermissionsResponse_get_class_data()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(from._impl_) {
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}
PROTOBUF_NDEBUG_INLINE checkIPCPermissionsResponse::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void checkIPCPermissionsResponse::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.permit_ = {};
}
checkIPCPermissionsResponse::~checkIPCPermissionsResponse() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.checkIPCPermissionsResponse)
  SharedDtor(*this);
}
inline void checkIPCPermissionsResponse::SharedDtor(MessageLite& self) {
  checkIPCPermissionsResponse& this_ = static_cast<checkIPCPermissionsResponse&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull checkIPCPermissionsResponse_class_data_ =
        checkIPCPermissionsResponse::InternalGenerateClassData_(checkIPCPermissionsResponse_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
checkIPCPermissionsResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&checkIPCPermissionsResponse_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(checkIPCPermissionsResponse_class_data_.tc_table);
  return checkIPCPermissionsResponse_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
checkIPCPermissionsResponse::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&checkIPCPermissionsResponse_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&checkIPCPermissionsResponse_globals_));
  return checkIPCPermissionsResponse_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const checkIPCPermissionsResponse::ParseTableT_
    checkIPCPermissionsResponse::_table_ =
        checkIPCPermissionsResponse::InternalGenerateParseTable_(checkIPCPermissionsResponse_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void checkIPCPermissionsResponse::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.checkIPCPermissionsResponse)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  this_._impl_.permit_ = false;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL checkIPCPermissionsResponse::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const checkIPCPermissionsResponse& this_ = static_cast<const checkIPCPermissionsResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL checkIPCPermissionsResponse::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const checkIPCPermissionsResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.checkIPCPermissionsResponse)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required bool permit = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        1, this_._internal_permit(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.checkIPCPermissionsResponse)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t checkIPCPermissionsResponse::ByteSizeLong(const MessageLite& base) {
  const checkIPCPermissionsResponse& this_ = static_cast<const checkIPCPermissionsResponse&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t checkIPCPermissionsResponse::ByteSizeLong() const {
  const checkIPCPermissionsResponse& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.checkIPCPermissionsResponse)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += static_cast<bool>(0x00000001U & cached_has_bits) * 2;
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void checkIPCPermissionsResponse::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<checkIPCPermissionsResponse*>(&to_msg);
  auto& from = static_cast<const checkIPCPermissionsResponse&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.checkIPCPermissionsResponse)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_impl_.permit_ = from._impl_.permit_;
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void checkIPCPermissionsResponse::CopyFrom(const checkIPCPermissionsResponse& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.checkIPCPermissionsResponse)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool checkIPCPermissionsResponse::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const checkIPCPermissionsResponse&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  return true;
}

void checkIPCPermissionsResponse::InternalSwap(checkIPCPermissionsResponse* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.permit_, other->_impl_.permit_);
}

::google::protobuf::Metadata checkIPCPermissionsResponse::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void checkIPCPermissions::clear_header() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.header_ != nullptr) _impl_.header_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
checkIPCPermissions::checkIPCPermissions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, checkIPCPermissions_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:usbguard.IPC.checkIPCPermissions)
}
PROTOBUF_NDEBUG_INLINE checkIPCPermissions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::usbguard::IPC::checkIPCPermissions& from_msg)
      : _has_bits_{from._has_bits_} {}

checkIPCPermissions::checkIPCPermissions(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const checkIPCPermissions& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : Super_(arena, checkIPCPermissions_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : Super_(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  checkIPCPermissions* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.header_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                 ? Super_::CopyConstruct(arena, *from._impl_.header_)
                 : nullptr;
  _impl_.request_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                 ? Super_::CopyConstruct(arena, *from._impl_.request_)
                 : nullptr;
  _impl_.response_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                 ? Super_::CopyConstruct(arena, *from._impl_.response_)
                 : nullptr;

  // @@protoc_insertion_point(copy_constructor:usbguard.IPC.checkIPCPermissions)
}
PROTOBUF_NDEBUG_INLINE checkIPCPermissions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
     {}

inline void checkIPCPermissions::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, header_),
           0,
           offsetof(Impl_, response_) -
               offsetof(Impl_, header_) +
               sizeof(Impl_::response_));
}
checkIPCPermissions::~checkIPCPermissions() {
  // @@protoc_insertion_point(destructor:usbguard.IPC.checkIPCPermissions)
  SharedDtor(*this);
}
inline void checkIPCPermissions::SharedDtor(MessageLite& self) {
  checkIPCPermissions& this_ = static_cast<checkIPCPermissions&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.header_;
  delete this_._impl_.request_;
  delete this_._impl_.response_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull checkIPCPermissions_class_data_ =
        checkIPCPermissions::InternalGenerateClassData_(checkIPCPermissions_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
checkIPCPermissions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&checkIPCPermissions_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(checkIPCPermissions_class_data_.tc_table);
  return checkIPCPermissions_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
checkIPCPermissions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&checkIPCPermissions_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&checkIPCPermissions_globals_));
  return checkIPCPermissions_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const checkIPCPermissions::ParseTableT_
    checkIPCPermissions::_table_ =
        checkIPCPermissions::InternalGenerateParseTable_(checkIPCPermissions_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void checkIPCPermissions::Clear() {
  auto& this_ [[maybe_unused]] = *this;
  // @@protoc_insertion_point(message_clear_start:usbguard.IPC.checkIPCPermissions)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(this_._impl_.header_ != nullptr);
      this_._impl_.header_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(this_._impl_.request_ != nullptr);
      this_._impl_.request_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(this_._impl_.response_ != nullptr);
      this_._impl_.response_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL checkIPCPermissions::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const checkIPCPermissions& this_ = static_cast<const checkIPCPermissions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL checkIPCPermissions::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const checkIPCPermissions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:usbguard.IPC.checkIPCPermissions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // required .usbguard.IPC.MessageHeader header = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.header_, this_._impl_.header_->GetCachedSize(), target,
        stream);
  }

  // required .usbguard.IPC.checkIPCPermissionsRequest request = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.request_, this_._impl_.request_->GetCachedSize(), target,
        stream);
  }

  // optional .usbguard.IPC.checkIPCPermissionsResponse response = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        3, *this_._impl_.response_, this_._impl_.response_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:usbguard.IPC.checkIPCPermissions)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t checkIPCPermissions::ByteSizeLong(const MessageLite& base) {
  const checkIPCPermissions& this_ = static_cast<const checkIPCPermissions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t checkIPCPermissions::ByteSizeLong() const {
  const checkIPCPermissions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:usbguard.IPC.checkIPCPermissions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits [[maybe_unused]] = 0;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // required .usbguard.IPC.MessageHeader header = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.header_);
    }
    // required .usbguard.IPC.checkIPCPermissionsRequest request = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.request_);
    }
  }
   {
    // optional .usbguard.IPC.checkIPCPermissionsResponse response = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.response_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void checkIPCPermissions::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<checkIPCPermissions*>(&to_msg);
  auto& from = static_cast<const checkIPCPermissions&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:usbguard.IPC.checkIPCPermissions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.header_ != nullptr);
      if (_this->_impl_.header_ == nullptr) {
        _this->_impl_.header_ = Super_::CopyConstruct(arena, *from._impl_.header_);
      } else {
        _this->_impl_.header_->MergeFrom(*from._impl_.header_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.request_ != nullptr);
      if (_this->_impl_.request_ == nullptr) {
        _this->_impl_.request_ = Super_::CopyConstruct(arena, *from._impl_.request_);
      } else {
        _this->_impl_.request_->MergeFrom(*from._impl_.request_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.response_ != nullptr);
      if (_this->_impl_.response_ == nullptr) {
        _this->_impl_.response_ = Super_::CopyConstruct(arena, *from._impl_.response_);
      } else {
        _this->_impl_.response_->MergeFrom(*from._impl_.response_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void checkIPCPermissions::CopyFrom(const checkIPCPermissions& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:usbguard.IPC.checkIPCPermissions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool checkIPCPermissions::IsInitializedImpl(
    const MessageLite& msg) {
  auto& this_ = static_cast<const checkIPCPermissions&>(msg);
  if (_Internal::MissingRequiredFields(this_._impl_._has_bits_)) {
    return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000001U)) {
    if (!this_._impl_.header_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000002U)) {
    if (!this_._impl_.request_->IsInitialized()) return false;
  }
  if (CheckHasBit(this_._impl_._has_bits_[0], 0x00000004U)) {
    if (!this_._impl_.response_->IsInitialized()) return false;
  }
  return true;
}

void checkIPCPermissions::InternalSwap(checkIPCPermissions* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.response_)
      + sizeof(checkIPCPermissions::_impl_.response_)
      - PROTOBUF_FIELD_OFFSET(checkIPCPermissions, _impl_.header_)>(
          reinterpret_cast<char*>(&_impl_.header_),
          reinterpret_cast<char*>(&other->_impl_.header_));
}

::google::protobuf::Metadata checkIPCPermissions::GetMetadata() const {
  return Super_::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace IPC
}  // namespace usbguard
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_Policy_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
#endif
